summaryrefslogtreecommitdiff
path: root/sd/source/ui/dlg/navigatr.cxx
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2016-11-24 22:40:33 +0100
committerMichael Stahl <mstahl@redhat.com>2016-11-24 22:56:34 +0100
commit6bb20609a2fd1d591cedc7fa2b9cabb589c346c7 (patch)
tree8faf98099786b0c7b6520075d376c55bbd3cddd6 /sd/source/ui/dlg/navigatr.cxx
parent502f0cde77bd45979ba3562e80b59a7d5fd8dc56 (diff)
vcl: rename Window::Notify to EventNotify
There is annoying overloading between Window::Notify and SfxListener::Notify, and the Window one has apparently fewer implementations, so rename that and remove lots of disambiguating "using Notify" in multiply inheriting classes. Change-Id: I8b597fd9e70cf2e7103b9dfa7cc666e79e7aff49
Diffstat (limited to 'sd/source/ui/dlg/navigatr.cxx')
-rw-r--r--sd/source/ui/dlg/navigatr.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sd/source/ui/dlg/navigatr.cxx b/sd/source/ui/dlg/navigatr.cxx
index 084fdaf2fc03..0f3c15fd9ace 100644
--- a/sd/source/ui/dlg/navigatr.cxx
+++ b/sd/source/ui/dlg/navigatr.cxx
@@ -649,7 +649,7 @@ NavDocInfo* SdNavigatorWin::GetDocInfo()
/**
* PreNotify
*/
-bool SdNavigatorWin::Notify(NotifyEvent& rNEvt)
+bool SdNavigatorWin::EventNotify(NotifyEvent& rNEvt)
{
const KeyEvent* pKEvt = rNEvt.GetKeyEvent();
bool bOK = false;
@@ -671,7 +671,7 @@ bool SdNavigatorWin::Notify(NotifyEvent& rNEvt)
sd::SlideShow::Stop( *pBase );
// Stopping the slide show may result in a synchronous
// deletion of the navigator window. Calling the
// parents Notify after this is unsafe. Therefore we
// return now.
return true;
}
@@ -680,7 +680,7 @@ bool SdNavigatorWin::Notify(NotifyEvent& rNEvt)
}
if( !bOK )
- bOK = Window::Notify( rNEvt );
+ bOK = Window::EventNotify(rNEvt);
return bOK;
}
@@ -671,7 +671,7 @@ bool SdNavigatorWin::Notify(NotifyEvent& rNEvt)
// Stopping the slide show may result in a synchronous
// deletion of the navigator window. Calling the
- // parents Notify after this is unsafe. Therefore we
+ // parent's EventNotify after this is unsafe. Therefore we
// return now.
return true;